import { DateFormatEnum, DatePickerModeEnum } from "../typings/enum/common.enum";
import { useMemoizedFn } from 'ahooks';
import dayjs from 'dayjs';
import dayOfYear from 'dayjs/plugin/dayOfYear';
import advancedFormat from 'dayjs/plugin/advancedFormat';
dayjs.extend(dayOfYear);
dayjs.extend(advancedFormat);
var useGetDateFormat = function useGetDateFormat(opt) {
  var _opt$picker = opt.picker,
    picker = _opt$picker === void 0 ? DatePickerModeEnum.DATE : _opt$picker,
    _opt$savedFormat = opt.savedFormat,
    savedFormat = _opt$savedFormat === void 0 ? DateFormatEnum.DATE_TIME : _opt$savedFormat;
  // 日期对外展示转换函数
  var formatter = useMemoizedFn(function (value) {
    if (value) {
      var dateVal = dayjs(value, savedFormat); // Dayjs格式的日期对象
      switch (picker) {
        case DatePickerModeEnum.WEEK:
          {
            // 此时的value为当前周的第一天的时间
            // 显示策略为：周一为哪个月的，显示为当前月的第几周，而不是下个月的第一周；下一周为下个月的第二周，没有第一周；
            var dayMonth = dateVal.date(); // 当前时间是当月的第几天
            var dayWeek = dateVal.day() + 1; // 当前时间是当周的第几天, 1-7
            var firstWeekDays = dayMonth % 7 - dayWeek; // 当前月的第一周有几天
            firstWeekDays = firstWeekDays >= 0 ? firstWeekDays : firstWeekDays + 7;
            var isFullWeek = firstWeekDays === 0; // 当月的第一天是不是周一
            var weekOfMonth = Math.ceil((dayMonth - firstWeekDays) / 7); // 日期处于那个月的第几周
            weekOfMonth = isFullWeek ? weekOfMonth : weekOfMonth + 1; // 月的第一天不在周一，则全部周数+1
            return "".concat(dateVal.format('YYYY'), "\u5E74 ").concat(dateVal.format('M'), "\u6708 \u7B2C").concat(weekOfMonth, "\u5468");
          }
        case DatePickerModeEnum.MONTH:
          {
            dateVal.date(1); // 设定日期为选中月的第一天
            return "".concat(dateVal.format('YYYY'), "\u5E74 ").concat(dateVal.format('M'), "\u6708");
          }
        case DatePickerModeEnum.QUARTER:
          {
            dateVal.date(1); // 设定日期为选中季的第一天
            return "".concat(dateVal.format('YYYY'), "\u5E74 \u7B2C").concat(dateVal.format('Q'), "\u5B63");
          }
        case DatePickerModeEnum.YEAR:
          {
            dateVal.dayOfYear(1); // 设定日期为选中年的第一天
            return "".concat(dateVal.format('YYYY'), "\u5E74");
          }
        default:
          {
            return value;
          }
      }
    }
    return '';
  });
  return {
    formatter: formatter
  };
};
export default useGetDateFormat;